@@ -14,8 +14,11 @@ fn conversions() -> () {
    println!("Slice-> {}",OrderedSet::from_slice(&v,true)); // sorted data but index lost
    println!("Set-> {}",OrderedSet::from_set(&setv,false)); // descending sorted data, index lost  
    let ix = IndexedSet::from_set(&setv,false);    
-   println!("Set-> {}",&ix); 
-   println!("Indexed-> {}",OrderedSet::from_indexed(&ix,false));
+   println!("Set-> {}",&ix);
+   let ss = OrderedSet::from_indexed(&ix,false); 
+   println!("Indexed-> {}",ss); 
+   println!("Ordered-> {}",IndexedSet::from_ordered(&ss,false)); 
+   println!("Ordered-> {}",RankedSet::from_ordered(&ss,true)); 
    let rx = RankedSet::from_slice(&v,false);
    println!("Slice->{}",&rx);
    println!("Ranked->{}",IndexedSet::from_ranked(&rx,true)); 
@@ -32,7 +35,7 @@ fn settest() -> () {
    println!("Reverse-> {}",setv.reverse()); 
    println!("Nonrepeat-> {}",setv.nonrepeat()); // Display of Set    
    println!("Is {} a member? {}\n",wi(&0.0),wi(&setv.member(0.0))); 
-   println!("Infsup: {}",wt(&setv.infsup()));
+   println!("Infsup: {}",setv.infsup());
    let setw = RankedSet::from_slice(&[20.,19.,18.,17.,16.,15.],true);
    println!("{}",setw);
    let us = setw.union(&setv);
@@ -69,7 +72,7 @@ fn nlptest() -> () {
    println!("Reverse-> {}",setv.reverse()); 
    println!("Nonrepeat-> {}",setv.nonrepeat()); // Display of Set    
    println!("Is {} a member? {}\n",wi(&"Spain"),wi(&setv.member("Spain"))); 
-   println!("Infsup: {}",wt(&setv.infsup()));
+   println!("Infsup: {}",setv.infsup());
    let setw = RankedSet::from_slice(&v2,true);
    println!("{}",setw);
    let us = setw.union(&setv);
